"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var lodash_1 = __importDefault(require("lodash"));
var LogService = (function () {
    function LogService(bundle, tracer) {
        this.bundle = bundle;
        this.tracer = tracer;
    }
    LogService.prototype.log = function (eventName, app, message) {
        console.log(eventName);
        var span = this.beginTrace(eventName, app);
        if (message) {
            span.log({
                message: message,
            });
        }
        span.finish();
    };
    LogService.prototype.beginTrace = function (eventName, app) {
        return this.tracer.startSpan(eventName, {
            tags: this.buildDefaultTags(app),
        });
    };
    LogService.prototype.buildLogMessage = function (message, app) {
        if (app === void 0) { app = null; }
        var messageLines = lodash_1.default.isString(message)
            ? message.split("\n")
            : [message];
        var logLinePrefix = this.buildDefaultTags(app);
        return lodash_1.default.map(messageLines, function (messageLine) { return "" + logLinePrefix + messageLine; });
    };
    LogService.prototype.buildDefaultTags = function (app) {
        return {
            "framework": "protoculture",
            "bundle": this.bundle.name,
            "app": app ? app.name : null,
        };
    };
    return LogService;
}());
exports.LogService = LogService;
//# sourceMappingURL=LogService.js.map